<?php

namespace Pinpoint\SnowdogMenuGraphQl\Model\Resolver\DataProvider;

use Magento\Framework\Api\SearchCriteriaBuilder;
use Magento\Framework\Exception\NoSuchEntityException;
use Snowdog\Menu\Model\Menu as MenuModel;
use Snowdog\Menu\Model\Menu\NodeRepository;
use Snowdog\Menu\Model\MenuRepository;

/**
 * Menu Data Provider.
 */
class Menu
{
    /**
     * @var SearchCriteriaBuilder
     */
    protected $searchCriteriaBuilder;

    /**
     * @var MenuRepository
     */
    protected $menuRepository;

    /**
     * @var NodeRepository
     */
    protected $nodeRepository;

    /**
     * @param SearchCriteriaBuilder $searchCriteriaBuilder
     * @param MenuRepository $menuRepository
     * @param NodeRepository $nodeRepository
     */
    public function __construct(
        SearchCriteriaBuilder $searchCriteriaBuilder,
        MenuRepository $menuRepository,
        NodeRepository $nodeRepository
    ) {
        $this->searchCriteriaBuilder = $searchCriteriaBuilder;
        $this->menuRepository = $menuRepository;
        $this->nodeRepository = $nodeRepository;
    }

    /**
     * @param int $menuId
     * @return MenuModel
     * @throws NoSuchEntityException
     */
    public function getMenu(int $menuId): MenuModel
    {
        return $this->menuRepository->getById($menuId);
    }

    /**
     * @param int $menuId
     * @return array
     */
    public function getNodes(int $menuId): array
    {
        $data = [];
        $nodes = $this->nodeRepository->getByMenu($menuId);
        foreach ($nodes as $node) {
            $data[] = [
                'name' => $node['title'],
                'cssClass' => $node['classes'],
                'nodeType' => $node['type'],
                'content' => $node['content'],
                'position' => $node['position'],
                'id' => $node['node_id'],
                'parent' => $node['parent_id'] ?? 0,
                'level' => $node['level'],
            ];
        }
        return $data;
    }
}
